@@ -8,7 +8,7 @@ from .global_constructionset import GlobalConstructionSet
 from .construction import OpaqueConstructionAbridged, WindowConstructionAbridged, \
     ShadeConstruction, AirBoundaryConstructionAbridged, OpaqueConstruction, \
     WindowConstruction, AirBoundaryConstruction, WindowConstructionShadeAbridged, \
-    WindowConstructionShade
+    WindowConstructionShade, WindowConstructionDynamicAbridged, WindowConstructionDynamic
 from .material import EnergyMaterial, EnergyMaterialNoMass, \
     EnergyWindowMaterialGas, EnergyWindowMaterialGasCustom, \
     EnergyWindowMaterialGasMixture, EnergyWindowMaterialSimpleGlazSys, \
@@ -16,7 +16,7 @@ from .material import EnergyMaterial, EnergyMaterialNoMass, \
 from .programtype import ProgramTypeAbridged, ProgramType
 from .load import PeopleAbridged, LightingAbridged, ElectricEquipmentAbridged, \
     GasEquipmentAbridged, ServiceHotWaterAbridged, InfiltrationAbridged, \
-    VentilationAbridged, SetpointAbridged
+    VentilationAbridged, SetpointAbridged, ProcessAbridged
 from .daylight import DaylightingControl
 from .ventcool import VentilationControlAbridged, VentilationOpening, \
     VentilationSimulationControl, AFNCrack
@@ -28,6 +28,7 @@ from .hvac.allair import VAV, PVAV, PSZ, PTAC, ForcedAirFurnace
 from .hvac.doas import FCUwithDOASAbridged, WSHPwithDOASAbridged, VRFwithDOASAbridged
 from .hvac.heatcool import FCU, WSHP, VRF, Baseboard, EvaporativeCooler, Residential, \
     WindowAC, GasUnitHeater
+from .shw import SHWSystem
 
 
 class ShadeEnergyPropertiesAbridged(NoExtraBaseModel):
@@ -152,6 +153,16 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         'that the Room is not conditioned.'
     )
 
+    shw: str = Field(
+        default=None,
+        min_length=1,
+        max_length=100,
+        description='An optional identifier of a Service Hot Water (SHW) system '
+        'that specifies how the hot water load of the Room is met. If None, the hot '
+        'water load will be met with a generic system that only measures thermal load'
+        'and does not account for system efficiencies.'
+    )
+
     people: PeopleAbridged = Field(
         default=None,
         description='People object to describe the occupancy of the Room.'
@@ -215,6 +226,15 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         'of the Room by undergoing heat transfer with the indoor air.'
     )
 
+    process_loads: List[ProcessAbridged] = Field(
+        default=None,
+        description='An optional list of of Process objects for process loads within '
+        'the room. These can represent kilns, manufacturing equipment, and various '
+        'industrial processes. They can also be used to represent wood burning '
+        'fireplaces or certain pieces of equipment to be separated from the other '
+        'end uses.'
+    )
+
 
 class ModelEnergyProperties(NoExtraBaseModel):
 
@@ -236,6 +256,7 @@ class ModelEnergyProperties(NoExtraBaseModel):
         OpaqueConstructionAbridged, WindowConstructionAbridged,
         WindowConstructionShadeAbridged, AirBoundaryConstructionAbridged,
         OpaqueConstruction, WindowConstruction, WindowConstructionShade,
+        WindowConstructionDynamicAbridged, WindowConstructionDynamic,
         AirBoundaryConstruction, ShadeConstruction]] = Field(
         default=None,
         description='A list of all unique constructions in the model. This includes '
@@ -261,6 +282,11 @@ class ModelEnergyProperties(NoExtraBaseModel):
         description='List of all unique HVAC systems in the Model.'
     )
 
+    shws: List[SHWSystem] = Field(
+        default=None,
+        description='List of all unique Service Hot Water (SHW) systems in the Model.'
+    )
+
     program_types: List[Union[ProgramTypeAbridged, ProgramType]] = Field(
         default=None,
         description='List of all unique ProgramTypes in the Model.'
